## R codes for simulation studies presented in Reich BJ, Bandyopadhyay D and Bondell H. (2013). A nonparametric spatial model for 
## periodontal data with non-random missingness, Journal of the American Statistical Association, 108, 820-831.
## We are using R MPI that facilitates computing. 
## "call_callsim.R" is the main file to run, which calls all other files 





# Load the R MPI package if it is not already loaded.
if (!is.loaded("mpi_initialize")) {
	library("Rmpi")
}



# Spawn as many slaves as possible

mpi.spawn.Rslaves()

# In case R exits unexpectedly, have it automatically clean up
# resources taken up by Rmpi (slaves, memory, etc...)
.Last <- function(){
	if (is.loaded("mpi_initialize")){
		if (mpi.comm.size(1) > 0){
			print("Please use mpi.close.Rslaves() to close slaves.")
				mpi.close.Rslaves()
		}
		print("Please use mpi.quit() to quit R")
			.Call("mpi_finalize")
	}
}


## Change model here
model<- 1



mpi.bcast.Robj2slave(model)


source("./callsim.R")
# Tell all slaves to close down, and exit the program
mpi.close.Rslaves()
mpi.quit(save="no")
